kerneltest/f32test/fsstress/t_sesfs.cpp
changeset 109 b3a1d9898418
parent 33 0173bcd7697c
child 257 3e88ff8f41d5
--- a/kerneltest/f32test/fsstress/t_sesfs.cpp	Mon May 03 13:47:38 2010 +0300
+++ b/kerneltest/f32test/fsstress/t_sesfs.cpp	Fri May 14 17:13:29 2010 +0300
@@ -262,20 +262,24 @@
 	test(w.iDrive.iDriveAtt==KDriveAttSubsted);
 	test(w.iDrive.iMediaAtt==v.iDrive.iMediaAtt);
 	test(w.iUniqueID==v.iUniqueID);
-	test(w.iSize==v.iSize);
 
-// If this test is being run under windows using drive C then skip free space comparison
-// as it is likely to fail as the windows file system is unlike to have static freespace
+    if(v.iDrive.iType != EMediaRam) // We can't assume that RAM disk will be the same size since last recorded...
+    {
+	    test(w.iSize==v.iSize);
+
+    // If this test is being run under windows using drive C then skip free space comparison
+    // as it is likely to fail as the windows file system is unlike to have static freespace
 #ifdef __WINS__
-	if(User::UpperCase(gTestSessionPath[0]) != 'C')
-		{
+	    if(User::UpperCase(gTestSessionPath[0]) != 'C')
+		    {
 #endif
-		test(w.iFree==v.iFree);
+		    test(w.iFree==v.iFree);
 
 #ifdef __WINS__
-		}
+		    }
 #endif
-	
+    }
+
 	test(w.iName==v.iName);
 	TDriveList driveList;
 	r=iFs.DriveList(driveList);